##
##  libressl.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libressl
Summary:      Cryptography and TLS/SSL Library Derived from OpenSSL
URL:          http://libressl.org/
Vendor:       OpenSSL Project, OpenBSD Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Cryptography
License:      OpenSSL
Version:      3.9.2
Release:      20240512

#   package options
%option       with_openssl  no

#   list of sources
Source0:      http://ftp.openbsd.org/pub/OpenBSD/LibreSSL/libressl-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    LibreSSL is a version of the TLS/crypto stack forked from OpenSSL in
    2014, with goals of modernizing the codebase, improving security,
    and applying best practice development processes.

%track
    prog libressl = {
        version   = %{version}
        url       = http://ftp.openbsd.org/pub/OpenBSD/LibreSSL/
        regex     = libressl-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
%if "%{with_openssl}" != "yes"
    mv  $RPM_BUILD_ROOT%{l_prefix}/bin/openssl \
        $RPM_BUILD_ROOT%{l_prefix}/bin/libressl
    mkdir \
        $RPM_BUILD_ROOT%{l_prefix}/include/libressl
    mv  $RPM_BUILD_ROOT%{l_prefix}/include/openssl \
        $RPM_BUILD_ROOT%{l_prefix}/include/libressl/
    mkdir \
        $RPM_BUILD_ROOT%{l_prefix}/lib/libressl
    mv  $RPM_BUILD_ROOT%{l_prefix}/lib/libcrypto* \
        $RPM_BUILD_ROOT%{l_prefix}/lib/libssl* \
        $RPM_BUILD_ROOT%{l_prefix}/lib/libressl/
    rm -f \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/libcrypto.pc \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/libssl.pc \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/openssl.pc
    ( cd $RPM_BUILD_ROOT%{l_prefix}/man
      for dir in man[1-9]; do
          for file in `cd $dir; echo *`; do
              mv $dir/$file $dir/libressl_$file
          done
      done
    ) || exit $?
%endif
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

